jdk/test/sun/net/www/protocol/http/B6296310.java
changeset 13788 3f38e525f30a
parent 5506 202f599c92aa
child 14342 8435a30053c1
--- a/jdk/test/sun/net/www/protocol/http/B6296310.java	Fri Sep 07 14:00:31 2012 +0100
+++ b/jdk/test/sun/net/www/protocol/http/B6296310.java	Fri Sep 07 15:30:17 2012 +0100
@@ -25,7 +25,7 @@
  * @test
  * @bug 6296310
  * @library ../../httptest/
  * @build HttpCallback HttpServer HttpTransaction
  * @run main/othervm B6296310
  * @summary  REGRESSION: AppletClassLoader.getResourceAsStream() behaviour is wrong in some cases
  */
@@ -42,7 +42,7 @@
 public class B6296310
 {
    static SimpleHttpTransaction httpTrans;
-   static HttpServer server;
+   static TestHttpServer server;
 
    public static void main(String[] args)
    {
@@ -55,7 +55,7 @@
    public static void startHttpServer() {
       try {
          httpTrans = new SimpleHttpTransaction();
-         server = new HttpServer(httpTrans, 1, 10, 0);
+         server = new TestHttpServer(httpTrans, 1, 10, 0);
       } catch (IOException e) {
          e.printStackTrace();
       }
@@ -25,7 +25,7 @@
  * @bug 6296310
  * @library ../../httptest/
- * @build HttpCallback HttpServer HttpTransaction
+ * @build HttpCallback TestHttpServer HttpTransaction
  * @run main/othervm B6296310
  * @summary  REGRESSION: AppletClassLoader.getResourceAsStream() behaviour is wrong in some cases